==> fr-facturier-2.1.1.tbz: www/facturier/lib/Conf.pm <==
#####
#
# Copyright (C) 2002 UNGI
#
# This file is part of UNGI facturier
#
# UNGI Facturier is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# UNGI Facturier is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#####
#
# Visit us!
#
# http://www.ungi.net
# http://ignu.ungi.org
#
#####

=pod
	variables de connection et constante
=cut


package Conf;
use strict;

BEGIN{
	use Exporter;
	use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
	$VERSION = 1.00;
	@ISA = qw(Exporter);
	@EXPORT= qw($HTMLADRESSE   $BASEAD $LIBAD $HTMLDOC
	$ErrConn   $conscde $CGIADR  $FACTUREAD
	   @connect
	 $tvaconst  $euro $mail $nblig
	 $constbank $BASEADHTML  $scriptdepart $nbligstat  $nbligfact 
	 $defaultpayment
	  @barrehautdroit $customer $root  
	  $BASEADHTMLTHEME $BASEADHTMLTMP $HTMLADRUNGI $HTMLADRUNGICONES
	  $logofacture $coord1 $coord2 $coordhautfax $coordbasfax $coordbasfact
	  $ordre $moiscomptable $symbolemonet $nbmaxnavig
	  $maxrelance $maxrelancefax $maxcar $pourcretard $signature
	  $LOGSIZE $MAXLOG
	  );
}

use vars   @EXPORT;

##############################
#variables serveur  configurer

=head2 debut configuration connection  base de donnes

pour se connecter  sql server il faut: dbd::odbc
pour se connecter  mysql il faut: dbd:mysql

=cut


#$USERBDD  pour valeur le login d'un utilisateur pouvant se connecter
# la base de donne  'FACTURIER' sur le serveur MySQL
 #remplacer 'PROP_BD' par le login d'un utilisateur ayant le droit d'utiliser
 #la base de donne 'facturier' sur le serveur MySQL
my $USERBDD="PROP_BD";


#$MDPBDD contient la valeur du mot de passe de connection de l'utilisateur
 #$USERBDD au serveur MySQL
 #remplacer 'MDP_BD' par le mot de passe du login de l'utilisateur
 #ci-dessus
my $MDPBDD="MDP_BD";
 
#base de donnes du facturier
#vous n'aurez pas, normalement, besoin de modifier cette variable.
my $BASEBDD = "FACTURIER";

#serveur de base de donnees
#remplacer "localhost" par le nom du serveur hbergeant MySQL.
my $HOSTBDD = "localhost";


#driver de base de donnees
# si vous utilisez MySQL comme base de donnes, vous n'aurez pas  modifier cette variable.
my $DRIVERBDD = "mysql";


#$CONNECTBDD et @connect sont les variable de connexion  la base de donne
#elles utilise des variables dfinit plus haut. Si vous utilisez MySQL,
#vous n'aurez pas besoin de modifier leurs valeurs.
my $CONNECTBDD = "dbi:$DRIVERBDD:$BASEBDD:$HOSTBDD";
@connect =($CONNECTBDD,$USERBDD,$MDPBDD);

=pod
fin connection  base de donnes
=cut


 #$CGIADR contient la valeur du scriptalias pour le 'Facturier' sur le serveur web 
 #remplacer 'scriptalias' par le scriptalias du 'Facturier'
 #si scriptalias = fact alors
 #$CGIADR="/fact"; 
 $CGIADR="/fact";
 
 
 #$BASEAD contient le chemin absolu du rpertoire facturier sur le serveur 
 # o est install le 'Facturier'
 #remplacer 'chemin repertoire principale (facturier/)' par le chemin du repertoire
 #facturier : si le facturier est dans /var/www/html, alors :
 #$BASEAD ="/var/www/html/facturier";
 $BASEAD ="/usr/local/www/facturier/";

 
 
 #$HTMLDOC contient le chemin de la commande htmldoc
 #si la commande htmldoc que vous dsirez utiliser est dans "/usr/bin/" faire
 #$HTMLDOC="/usr/bin/htmldoc";
 $HTMLDOC="/usr/local/bin/htmldoc";
 
###################################
#finvariables serveur  configurer
##################################

#$BASEADHTML contient le chemin du repertoire html du rpertoire facturier sur le serveur
 $BASEADHTML="$BASEAD/html";
 $BASEADHTMLTHEME= "$BASEADHTML/UNGI";
 $BASEADHTMLTMP = "$BASEADHTML/temp";

#$LIBAD contient le chemin du repertoire lib du facturier sur le serveur
 $LIBAD="$BASEAD/lib";


 #$HTMLADRESSE indique au serveur web o se trouve les pages html utilises par le facturier
 # par apport au DocumentRoot. Si vous avez install le facturier dans le DocumentRoot
 #vous n'aurez pas besoin de modifier la valeur de $HTMLADRESSE
 $HTMLADRESSE='/../facturier/html';
 $HTMLADRUNGI = "$HTMLADRESSE/UNGI";
 $HTMLADRUNGICONES = "$HTMLADRUNGI/icones";
 

 #FACTUREAD = repertoire des factures stockes au format pdf
 $FACTUREAD ="$BASEAD/facture";


 #$mail contient l'adresse email  laquelle envoy un message lors de la cration
 #d'un commande (cf manuel utilisateur).
 #adresse mail si on dsire, mettre un '\' avant @, par ex : $mail='patron\@adr.net';
 #si l'adresse email est : "patron@adr.net 
 $mail="";
 
 #message d'erreur
 $ErrConn = "impossible de se connecter $!";  
 
 #script de depart
 $scriptdepart = "facture"; 
 
 #taux de tva
 $tvaconst="19.60";
 
 #valeur d'un euro en franc
 $euro=6.55957; 
 
 #nombre de lignes d'occurence d'un objet (factures, dpenses, ...) affiches
 #par dfaut par cran
 $nblig = 6;
 
 #nombre de lignes statistiques affiches  par dfaut dans la liste des statistiques
 $nbligstat=12;
 
 #nombre de lignes par facture 
 $nbligfact=14;
 
 #valeur du compte en banque de l'entreprise avant que vous ne crer votre 1re facture
 #ou dpense avec le 'Facturier'
 $constbank=0; 
 
 #mois depart annee comptable
 $moiscomptable = 9;

 #chance de paiement avec laquelle une facture est cre par dfaut, ici 30 pour 30 jours.
 $defaultpayment = 30;
 
 #liste des boutons de la barre de navigation
 @barrehautdroit= ("1", "2", "3", "4", "5", "6", "7","8", "9","10","11");
 
 #le seul utilisateur que l'on ne peut pas supprimer et dont on ne peut pas
 #modifier le mot de passe
 $root = 'admin';
 
 #sert  forcer  choisir un client dans la liste des noms de client
 #quand on cre un utilisateur de type 'client'
 $customer = "client"; 
 
 #pour l'edition de facture et des relances
 #logo facture, lettre et fax de relance
 $logofacture = "log_facture.gif";
 #symbole monetaire d'un facture
 $symbolemonet = "euro2.gif";

 #coord lettre de relance et facture
 $coord1 = q|<font face="Arial, Helvetica, sans-serif" size="2"><br><b>Sige Social <font class=font5>:</font></b>
        2, rue de la Piscine - 75021 Paris <br>
        <b>Adresse de correspondance :</b> <br>
        2 rue de la Piscine- 75021 Paris <br>
        <b>Tl :</b> 01 01 01 01 <br>
      <b>E-mail :</b> <a href="mail@mail">mail@mail</a></font>|;

#coord bas de facture
$coord2 = q|<td bgcolor="#FFFFFF"><font face="Arial, Helvetica, sans-serif" size="2" class="font5"><b>Compte
            :</b> PISCINE S.A.<br>
            <b>Domiciliation :</b> PISCINE<br>
            <b>Code Banque :</b> 0000<br>
            <b>Code Guichet :</b> 0000<br>
            <b>Cl&eacute; RIB :</b> 00</font></td>|;

$ordre = q|<p><font face="Arial, Helvetica, sans-serif" size="2"><i>Rglement par chque
         l'ordre de <b>NEANT<span style="mso-spacerun: yes"></span>SA</b></i></font><i><font class="font2" face="Arial, Helvetica, sans-serif" size="2">
        ou par virement au compte mentionn ci-dessus</font></i><font face="Arial, Helvetica, sans-serif" size="2"><br>|;

$coordbasfact = q|NEANT  000 000(000000) SIRET 000000000000|;

#coord haut de fax de relance
$coordhautfax = q|
            NEANT<br>la Piscine<br>
            75021 PARIS<br>
            TEl : 01 01 01 01 01 <br>
|;

$coordbasfax = q|
            <b><font size="2">Socit NEANT Paris - tel : 01 01 01
            01 01 - Fax : 01 01 01 01 01</font></b>
|;

$signature = "Facturier";

#pour le maximum de relance
$maxrelance = 3;
$maxrelance = 4;
$maxrelancefax = 2;
#nb de car max par ligne de facture pour le libelle
$maxcar = 50;
#pourcentage par mois de retard
$pourcretard = 0.10;
#nb de bouton max par ligne de barre de navigation
$nbmaxnavig = 6;

#taille max du fichier debug
#$LOGSIZE=2;
$LOGSIZE=250000;
# nb max de fichier debug
$MAXLOG=10;

 1;

 END{}

==> fr-facturier-2.1.2.tbz: www/facturier/lib/Conf.pm <==
#####
#
# Copyright (C) 2002 UNGI
#
# This file is part of UNGI facturier
#
# UNGI Facturier is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# UNGI Facturier is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#####
#
# Visit us!
#
# http://www.ungi.net
# http://ignu.ungi.org
#
#####

=pod
	variables de connection et constante
=cut


package Conf;
use strict;

BEGIN{
	use Exporter;
	use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
	$VERSION = 1.00;
	@ISA = qw(Exporter);
	@EXPORT= qw($HTMLADRESSE   $BASEAD $LIBAD $HTMLDOC
	$ErrConn   $conscde $CGIADR  $FACTUREAD
	   @connect
	 $tvaconst  $euro $mail $nblig
	 $constbank $BASEADHTML  $scriptdepart $nbligstat  $nbligfact 
	 $defaultpayment
	  @barrehautdroit $customer $root  
	  $BASEADHTMLTHEME $BASEADHTMLTMP $HTMLADRUNGI $HTMLADRUNGICONES
	  $logofacture $coord1 $coord2 $coordhautfax $coordbasfax $coordbasfact
	  $ordre $moiscomptable $symbolemonet $nbmaxnavig
	  $maxrelance $maxrelancefax $maxcar $pourcretard $signature
	  $LOGSIZE $MAXLOG
	  );
}

use vars   @EXPORT;

##############################
#variables serveur  configurer

=head2 debut configuration connection  base de donnes

pour se connecter  sql server il faut: dbd::odbc
pour se connecter  mysql il faut: dbd:mysql

=cut


#$USERBDD  pour valeur le login d'un utilisateur pouvant se connecter
# la base de donne  'FACTURIER' sur le serveur MySQL
 #remplacer 'PROP_BD' par le login d'un utilisateur ayant le droit d'utiliser
 #la base de donne 'facturier' sur le serveur MySQL
my $USERBDD="PROP_BD";


#$MDPBDD contient la valeur du mot de passe de connection de l'utilisateur
 #$USERBDD au serveur MySQL
 #remplacer 'MDP_BD' par le mot de passe du login de l'utilisateur
 #ci-dessus
my $MDPBDD="MDP_BD";
 
#base de donnes du facturier
#vous n'aurez pas, normalement, besoin de modifier cette variable.
my $BASEBDD = "FACTURIER";

#serveur de base de donnees
#remplacer "localhost" par le nom du serveur hbergeant MySQL.
my $HOSTBDD = "localhost";


#driver de base de donnees
# si vous utilisez MySQL comme base de donnes, vous n'aurez pas  modifier cette variable.
my $DRIVERBDD = "mysql";


#$CONNECTBDD et @connect sont les variable de connexion  la base de donne
#elles utilise des variables dfinit plus haut. Si vous utilisez MySQL,
#vous n'aurez pas besoin de modifier leurs valeurs.
my $CONNECTBDD = "dbi:$DRIVERBDD:$BASEBDD:$HOSTBDD";
@connect =($CONNECTBDD,$USERBDD,$MDPBDD);

=pod
fin connection  base de donnes
=cut


 #$CGIADR contient la valeur du scriptalias pour le 'Facturier' sur le serveur web 
 #remplacer 'scriptalias' par le scriptalias du 'Facturier'
 #si scriptalias = fact alors
 #$CGIADR="/fact"; 
 $CGIADR="/fact";
 
 
 #$BASEAD contient le chemin absolu du rpertoire facturier sur le serveur 
 # o est install le 'Facturier'
 #remplacer 'chemin repertoire principale (facturier/)' par le chemin du repertoire
 #facturier : si le facturier est dans /var/www/html, alors :
 #$BASEAD ="/var/www/html/facturier";
 $BASEAD ="/usr/local/www/facturier/";

 
 
 #$HTMLDOC contient le chemin de la commande htmldoc
 #si la commande htmldoc que vous dsirez utiliser est dans "/usr/bin/" faire
 #$HTMLDOC="/usr/bin/htmldoc";
 $HTMLDOC="/usr/local/bin/htmldoc";
###################################
#finvariables serveur  configurer
##################################

#$BASEADHTML contient le chemin du repertoire html du rpertoire facturier sur le serveur
 $BASEADHTML="$BASEAD/html";
 $BASEADHTMLTHEME= "$BASEADHTML/UNGI";
 $BASEADHTMLTMP = "$BASEADHTML/temp";

#$LIBAD contient le chemin du repertoire lib du facturier sur le serveur
 $LIBAD="$BASEAD/lib";


 #$HTMLADRESSE indique au serveur web o se trouve les pages html utilises par le facturier
 # par apport au DocumentRoot. Si vous avez install le facturier dans le DocumentRoot
 #vous n'aurez pas besoin de modifier la valeur de $HTMLADRESSE
 $HTMLADRESSE='/../facturier/html';
 $HTMLADRUNGI = "$HTMLADRESSE/UNGI";
 $HTMLADRUNGICONES = "$HTMLADRUNGI/icones";
 

 #FACTUREAD = repertoire des factures stockes au ormat pdf
 $FACTUREAD ="$BASEAD/facture";


 #$mail contient l'adresse email  laquelle envoy un message lors de la cration
 #d'un commande (cf manuel utilisateur).
 #adresse mail si on dsire, mettre un '\' avant @, par ex : $mail='patron\@adr.net';
 #si l'adresse email est : "patron@adr.net 
 $mail="";
 
 #message d'erreur
 $ErrConn = "impossible de se connecter $!";  
 
 #script de depart
 $scriptdepart = "facture"; 
 
 #taux de tva
 $tvaconst="19.60";
 
 #valeur d'un euro en franc
 $euro=6.55957; 
 
 #nombre de lignes d'occurence d'un objet (factures, dpenses, ...) affiches
 #par dfaut par cran
 $nblig = 6;
 
 #nombre de lignes statistiques affiches  par dfaut dans la liste des statistiques
 $nbligstat=12;
 
 #nombre de lignes par facture 
 $nbligfact=14;
 
 #valeur du compte en banque de l'entreprise avant que vous ne crer votre 1re facture
 #ou dpense avec le 'Facturier'
 $constbank=0; 
 
 #mois depart annee comptable
 $moiscomptable = 9;

 #chance de paiement avec laquelle une facture est cre par dfaut, ici 30 pour 30 jours.
 $defaultpayment = 30;
 
 #liste des boutons de la barre de navigation
 @barrehautdroit= ("1", "2", "3", "4", "5", "6", "7","8", "9","10","11");
 
 #le seul utilisateur que l'on ne peut pas supprimer et dont on ne peut pas
 #modifier le mot de passe
 $root = 'admin';
 
 #sert  forcer  choisir un client dans la liste des noms de client
 #quand on cre un utilisateur de type 'client'
 $customer = "client"; 
 
 #pour l'edition de facture et des relances
 #logo facture, lettre et fax de relance
 $logofacture = "log_facture.gif";
 #symbole monetaire d'un facture
 $symbolemonet = "euro2.gif";

 #coord lettre de relance et facture
 $coord1 = q|<font face="Arial, Helvetica, sans-serif" size="2"><br><b>Sige Social <font class=font5>:</font></b>
        2, rue de la Piscine - 75021 Paris <br>
        <b>Adresse de correspondance :</b> <br>
        2 rue de la Piscine- 75021 Paris <br>
        <b>Tl :</b> 01 01 01 01 <br>
      <b>E-mail :</b> <a href="mail@mail">mail@mail</a></font>|;

#coord bas de facture
$coord2 = q|<td bgcolor="#FFFFFF"><font face="Arial, Helvetica, sans-serif" size="2" class="font5"><b>Compte
            :</b> PISCINE S.A.<br>
            <b>Domiciliation :</b> PISCINE<br>
            <b>Code Banque :</b> 0000<br>
            <b>Code Guichet :</b> 0000<br>
            <b>Cl&eacute; RIB :</b> 00</font></td>|;

$ordre = q|<p><font face="Arial, Helvetica, sans-serif" size="2"><i>Rglement par chque
         l'ordre de <b>NEANT<span style="mso-spacerun: yes"></span>SA</b></i></font><i><font class="font2" face="Arial, Helvetica, sans-serif" size="2">
        ou par virement au compte mentionn ci-dessus</font></i><font face="Arial, Helvetica, sans-serif" size="2"><br>|;

$coordbasfact = q|NEANT  000 000(000000) SIRET 000000000000|;

#coord haut de fax de relance
$coordhautfax = q|
            NEANT<br>la Piscine<br>
            75021 PARIS<br>
            TEl : 01 01 01 01 01 <br>
|;

$coordbasfax = q|
            <b><font size="2">Socit NEANT Paris - tel : 01 01 01
            01 01 - Fax : 01 01 01 01 01</font></b>
|;

$signature = "Facturier";

#pour le maximum de relance
$maxrelance = 3;
$maxrelance = 4;
$maxrelancefax = 2;
#nb de car max par ligne de facture pour le libelle
$maxcar = 50;
#pourcentage par mois de retard
$pourcretard = 0.10;
#nb de bouton max par ligne de barre de navigation
$nbmaxnavig = 6;

#taille max du fichier debug
#$LOGSIZE=2;
$LOGSIZE=250000;
# nb max de fichier debug
$MAXLOG=10;

 1;

 END{}
